Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3522)

Unified Diff: chrome/renderer/content_settings_observer.h

Issue 1417033010: Adding <keygen> Content Setting (Blink) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@keygen_core
Patch Set: Rebase? Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/content_settings_observer.h
diff --git a/chrome/renderer/content_settings_observer.h b/chrome/renderer/content_settings_observer.h
index 37a70438c0c6657565877e219ac6202eb6b463ff..3559a324565989ab7bfbdf5c07c0c34a25d2fd87 100644
--- a/chrome/renderer/content_settings_observer.h
+++ b/chrome/renderer/content_settings_observer.h
@@ -77,6 +77,7 @@ class ContentSettingsObserver
bool allowMutationEvents(bool default_value) override;
void didNotAllowPlugins() override;
void didNotAllowScript() override;
+ void usedKeygen() override;
bool allowDisplayingInsecureContent(bool allowed_per_settings,
const blink::WebSecurityOrigin& context,
const blink::WebURL& url) override;
@@ -143,14 +144,14 @@ class ContentSettingsObserver
// |SetContentSettingRules|.
const RendererContentSettingRules* content_setting_rules_;
// Stores if images, scripts, and plugins have actually been blocked.
std::map<ContentSettingsType, bool> content_blocked_;
// Caches the result of AllowStorage.
typedef std::pair<GURL, bool> StoragePermissionsKey;
std::map<StoragePermissionsKey, bool> cached_storage_permissions_;
- // Caches the result of |AllowScript|.
+ // Caches the result of AllowScript.
std::map<blink::WebFrame*, bool> cached_script_permissions_;
std::set<std::string> temporarily_allowed_plugins_;
@@ -143,14 +144,14 @@ class ContentSettingsObserver
// |SetContentSettingRules|.
const RendererContentSettingRules* content_setting_rules_;
- // Stores if images, scripts, and plugins have actually been blocked.
+ // Stores if images, scripts, keygen, and plugins have actually been blocked.
std::map<ContentSettingsType, bool> content_blocked_;
// Caches the result of AllowStorage.

Powered by Google App Engine
This is Rietveld 408576698